import { renameKeysFromRESTResponseToSDKResponse } from '@wix/sdk-runtime/rename-all-nested-keys';
import { transformRESTFloatToSDKFloat } from '@wix/sdk-runtime/transformations/float';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { EventDefinition } from '@wix/sdk-types';
import { createGroup as universalCreateGroup, deleteGroup as universalDeleteGroup, getGroup as universalGetGroup, getGroupBySlug as universalGetGroupBySlug, listGroups as universalListGroups, queryGroups as universalQueryGroups, updateGroup as universalUpdateGroup, } from './social-groups-v2-group-groups.universal.js';
export const __metadata = { PACKAGE_NAME: '@wix/groups' };
export function createGroup(httpClient) {
    return (group, options) => universalCreateGroup(group, options, 
    // @ts-ignore
    { httpClient });
}
export function updateGroup(httpClient) {
    return (_id, group, options) => universalUpdateGroup(_id, group, options, 
    // @ts-ignore
    { httpClient });
}
export function deleteGroup(httpClient) {
    return (groupId) => universalDeleteGroup(groupId, 
    // @ts-ignore
    { httpClient });
}
export function getGroup(httpClient) {
    return (groupId, options) => universalGetGroup(groupId, options, 
    // @ts-ignore
    { httpClient });
}
export function getGroupBySlug(httpClient) {
    return (slug, options) => universalGetGroupBySlug(slug, options, 
    // @ts-ignore
    { httpClient });
}
export function listGroups(httpClient) {
    return (options) => universalListGroups(options, 
    // @ts-ignore
    { httpClient });
}
export function queryGroups(httpClient) {
    return (options) => universalQueryGroups(options, 
    // @ts-ignore
    { httpClient });
}
export const onGroupCreated = EventDefinition('wix.social_groups.v2.group_created', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'entity.updatedDate' },
            { path: 'entity.recentActivityDate' },
            { path: 'entity.lastActivityDate' },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            { path: 'entity.details.logoPosition.x' },
            { path: 'entity.details.logoPosition.y' },
            { path: 'entity.details.mobileLogoPosition.x' },
            { path: 'entity.details.mobileLogoPosition.y' },
            { path: 'entity.coverImage.position.x' },
            { path: 'entity.coverImage.position.y' },
            { path: 'entity.coverImage.mobilePosition.x' },
            { path: 'entity.coverImage.mobilePosition.y' },
        ],
    },
])))();
export const onGroupDeleted = EventDefinition('wix.social_groups.v2.group_deleted', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'undefined.createdDate' },
            { path: 'undefined.updatedDate' },
            { path: 'undefined.recentActivityDate' },
            { path: 'undefined.lastActivityDate' },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            { path: 'undefined.details.logoPosition.x' },
            { path: 'undefined.details.logoPosition.y' },
            { path: 'undefined.details.mobileLogoPosition.x' },
            { path: 'undefined.details.mobileLogoPosition.y' },
            { path: 'undefined.coverImage.position.x' },
            { path: 'undefined.coverImage.position.y' },
            { path: 'undefined.coverImage.mobilePosition.x' },
            { path: 'undefined.coverImage.mobilePosition.y' },
        ],
    },
])))();
export const onGroupCoverChanged = EventDefinition('wix.social_groups.v2.group_group_cover_changed', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [{ path: 'metadata.eventTime' }],
    },
])))();
export const onGroupDescriptionChanged = EventDefinition('wix.social_groups.v2.group_group_description_changed', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [{ path: 'metadata.eventTime' }],
    },
])))();
export const onGroupUpdated = EventDefinition('wix.social_groups.v2.group_updated', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'entity.updatedDate' },
            { path: 'entity.recentActivityDate' },
            { path: 'entity.lastActivityDate' },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            { path: 'entity.details.logoPosition.x' },
            { path: 'entity.details.logoPosition.y' },
            { path: 'entity.details.mobileLogoPosition.x' },
            { path: 'entity.details.mobileLogoPosition.y' },
            { path: 'entity.coverImage.position.x' },
            { path: 'entity.coverImage.position.y' },
            { path: 'entity.coverImage.mobilePosition.x' },
            { path: 'entity.coverImage.mobilePosition.y' },
        ],
    },
])))();
export { AllowPolicy, BMFeaturesBMFeatures, ContentType, IdentityType, MembershipStatus, PrivacyStatus, SortOrder, StepKey, Type, WebhookIdentityType, } from './social-groups-v2-group-groups.universal.js';
//# sourceMappingURL=social-groups-v2-group-groups.public.js.map